"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GameRecordCard = void 0;
const base_1 = require("./base");
const constants_1 = require("../constants/constants");
const utils_1 = require("../utils");
class GameRecordCard extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @param {string} uid HoYoLab Account ID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new utils_1.RequestManager({
            route: constants_1.API_URL.Genshin_HoYolab,
            language,
        });
        const res = await instance.get("getGameRecordCard", {
            Cookie: cookie,
        }, {
            uid: uid,
        });
        const { data } = res;
        (0, utils_1.removeFromObject)(data.list, ["h5_data_switches", "data_switches"]);
        const returnData = {
            list: data.list,
            current: data.list[0],
        };
        this.cache.set(uid, returnData);
        return returnData;
    }
}
exports.GameRecordCard = GameRecordCard;
