"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TCG = exports.GameRecord = void 0;
const base_1 = require("./base");
const utils_1 = require("../utils");
class BasicInfo extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new utils_1.RequestManager({
            withDS: true,
            withExtraHeaders: true,
            language,
        });
        const res = await instance.get("gcg/basicInfo", {
            Cookie: cookie,
        }, {
            server: (0, utils_1.checkServerRegion)(uid),
            role_id: uid,
        });
        const { data } = res;
        this.cache.set(uid, data);
        return data;
    }
}
class CardList extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        }, "CardListOptions");
        if (!(0, utils_1.cardListValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie, need_avatar, need_action, need_stats, offset, limit } = optionsToUse;
        const instance = new utils_1.RequestManager({
            withDS: true,
            withExtraHeaders: true,
            language,
        });
        const res = await instance.get("gcg/cardList", {
            Cookie: cookie,
        }, {
            server: (0, utils_1.checkServerRegion)(uid),
            role_id: uid,
            need_avatar: need_avatar ?? true,
            need_action: need_action ?? true,
            need_stats: need_stats ?? true,
            offset: offset ?? 0,
            limit: limit ?? 32,
        });
        const { data } = res;
        this.cache.set(uid, data);
        return data;
    }
}
class CardBackList extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new utils_1.RequestManager({
            withDS: true,
            withExtraHeaders: true,
            language,
        });
        const res = await instance.get("gcg/cardBackList", {
            Cookie: cookie,
        }, {
            server: (0, utils_1.checkServerRegion)(uid),
            role_id: uid,
        });
        const { data } = res;
        this.cache.set(uid, data);
        return data;
    }
}
class GameRecord extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new utils_1.RequestManager({
            withDS: true,
            withExtraHeaders: true,
            language,
        });
        const res = await instance.get("gcg/matchList", {
            Cookie: cookie,
        }, {
            server: (0, utils_1.checkServerRegion)(uid),
            role_id: uid,
        });
        const { data } = res;
        this.cache.set(uid, data);
        return data;
    }
}
exports.GameRecord = GameRecord;
class TCG {
    constructor(options) {
        Object.defineProperty(this, "basicInfo", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cardList", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cardBackList", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "gameRecord", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.basicInfo = new BasicInfo(options);
        this.cardList = new CardList(options);
        this.cardBackList = new CardBackList(options);
        this.gameRecord = new GameRecord(options);
    }
}
exports.TCG = TCG;
